@@ -27,7 +27,7 @@ import os
 import sys
 import textwrap
 
-from .builder import Build
+from .build import Build
 from .exceptions import eprint
 from .warner import ZCBEWarner
 
@@ -85,7 +85,7 @@ class AboutAction(argparse.Action):
 
 
 def start():
-    """ZCBE entrypoint. Parse arguments and invoke builder."""
+    """ZCBE entrypoint. Parse arguments."""
     # Set up the warner to use
     warner = ZCBEWarner()
     warner.load_default(set(ALL_WARNINGS), DEFAULT_WARNINGS)
@@ -135,6 +135,8 @@ def start():
                         " ('{n}' expands to the name of the project)")
     parser.add_argument("-f", "--file", "--build-toml", type=str,
                         default="build.toml", help="Read FILE as build.toml")
+    parser.add_argument("-j", "--jobs", type=int,
+                        help="Number of maximum concurrent jobs")
     parser.add_argument("-a", "--all", action="store_true",
                         help="Build all projects in mapping.toml")
     parser.add_argument("-s", "--silent", action="store_true",
@@ -154,17 +156,22 @@ def start():
         os.chdir(namespace.chdir)
     if namespace.silent:
         namespace.stdout_to = os.devnull
+    return asyncio.run(invoke_builder(namespace, warner))
+
+
+async def invoke_builder(namespace, warner):
+    """Invoke a builder with the arguments."""
     # Create builder instance
     builder = Build(".", warner, if_rebuild=namespace.rebuild,
                     if_dryrun=namespace.dry_run,
                     build_toml_filename=namespace.file,
                     stdout=namespace.stdout_to,
-                    stderr=namespace.stderr_to)
+                    stderr=namespace.stderr_to,
+                    max_jobs=namespace.jobs or 0)
     if namespace.show_unbuilt:
         return 0 if builder.show_unbuilt() else 1
     if namespace.all:
-        runner = builder.build_all()
+        result = await builder.build_all()
     else:
-        runner = builder.build_many(namespace.projects)
-    success = asyncio.run(runner)
-    return 0 if success else 1
+        result = await builder.build_many(namespace.projects)
+    return result
